@@ -1,3 +1,6 @@
+"""Shows how to use ordinal names for sorting.
+See https://pytest-dev.github.io/pytest-order/dev/#order-using-ordinals
+"""
 import pytest
 
 
