@@ -1,5 +1,5 @@
 import pytest
-from pytest_order.sorter import SESSION
+from pytest_order.settings import Scope
 
 pytest_plugins = ["pytester"]
 
@@ -14,8 +14,9 @@ def item_names_for(testdir):
 
         items = testdir.getitems(tests_content)
         hook = items[0].config.hook
-        hook.pytest_collection_modifyitems(session=items[0].session,
-                                           config=items[0].config, items=items)
+        hook.pytest_collection_modifyitems(
+            session=items[0].session, config=items[0].config, items=items
+        )
 
         return [name(item) for item in items]
 
@@ -25,7 +26,7 @@ def item_names_for(testdir):
 @pytest.fixture
 def test_path(testdir):
     testdir.tmpdir.join("pytest.ini").write(
-        "[pytest]\n" "console_output_style = classic"
+        "[pytest]\nconsole_output_style = classic"
     )
     yield testdir
 
@@ -35,8 +36,8 @@ def ignore_settings(mocker):
     settings = mocker.patch("pytest_order.sorter.Settings")
     settings.return_value.sparse_ordering = False
     settings.return_value.order_dependencies = False
-    settings.return_value.scope = SESSION
-    settings.return_value.group_scope = SESSION
+    settings.return_value.scope = Scope.SESSION
+    settings.return_value.group_scope = Scope.SESSION
     settings.return_value.scope_level = 0
     yield settings
 
