@@ -6,72 +6,82 @@ import pytest
 @pytest.fixture
 def fixture_path(test_path):
     test_path.makepyfile(
-        test_clss="""
-    import pytest
+        test_clss=(
+            """
+            import pytest
 
-    class Test1:
-        @pytest.mark.order(2)
-        def test_two(self):
-            assert True
+            class Test1:
+                @pytest.mark.order(2)
+                def test_two(self):
+                    assert True
 
-        def test_one(self):
-            assert True
+                def test_one(self):
+                    assert True
 
-    class Test2:
-        def test_two(self):
-            assert True
+            class Test2:
+                def test_two(self):
+                    assert True
 
-        @pytest.mark.order(1)
-        def test_one(self):
-            assert True
+                @pytest.mark.order(1)
+                def test_one(self):
+                    assert True
 
-    @pytest.mark.order(-1)
-    def test_two():
-        assert True
+            @pytest.mark.order(-1)
+            def test_two():
+                assert True
 
-    def test_one():
-        assert True
-    """,
-        test_fcts1="""
-    import pytest
+            def test_one():
+                assert True
+            """
+        ),
+        test_fcts1=(
+            """
+            import pytest
 
-    @pytest.mark.order(5)
-    def test1_two():
-        assert True
+            @pytest.mark.order(5)
+            def test1_two():
+                assert True
 
-    def test1_one():
-        assert True
-    """,
-        test_fcts2="""
-    import pytest
+            def test1_one():
+                assert True
+            """
+        ),
+        test_fcts2=(
+            """
+            import pytest
 
-    @pytest.mark.order(0)
-    def test2_two():
-        assert True
+            @pytest.mark.order(0)
+            def test2_two():
+                assert True
 
-    def test2_one():
-        assert True
-    """,
-        test_fcts3="""
-    import pytest
+            def test2_one():
+                assert True
+            """
+        ),
+        test_fcts3=(
+            """
+            import pytest
 
-    @pytest.mark.order(-2)
-    def test3_two():
-        assert True
+            @pytest.mark.order(-2)
+            def test3_two():
+                assert True
 
-    def test3_one():
-        assert True
-    """,
-        test_fcts4="""
-    import pytest
+            def test3_one():
+                assert True
+            """
+        ),
+        test_fcts4=(
+            """
+            import pytest
 
-    def test4_one():
-        assert True
-
-    def test4_two():
-        assert True
-    """)
+            def test4_one():
+                assert True
 
+            def test4_two():
+                assert True
+            """
+        ),
+    )
     yield test_path
 
 
@@ -92,7 +102,7 @@ def test_session_scope(fixture_path):
         "test_fcts4.py::test4_one PASSED",
         "test_fcts4.py::test4_two PASSED",
         "test_fcts3.py::test3_two PASSED",
-        "test_clss.py::test_two PASSED"
+        "test_clss.py::test_two PASSED",
     ])
 
 
@@ -113,7 +123,7 @@ def test_module_group_scope(fixture_path):
         "test_fcts4.py::test4_one PASSED",
         "test_fcts4.py::test4_two PASSED",
         "test_fcts3.py::test3_one PASSED",
-        "test_fcts3.py::test3_two PASSED"
+        "test_fcts3.py::test3_two PASSED",
     ])
 
 
@@ -134,13 +144,14 @@ def test_class_group_scope(fixture_path):
         "test_fcts4.py::test4_one PASSED",
         "test_fcts4.py::test4_two PASSED",
         "test_fcts3.py::test3_one PASSED",
-        "test_fcts3.py::test3_two PASSED"
+        "test_fcts3.py::test3_two PASSED",
     ])
 
 
 def test_class_group_scope_module_scope(fixture_path):
-    result = fixture_path.runpytest("-v", "--order-group-scope=class",
-                                    "--order-scope=module")
+    result = fixture_path.runpytest(
+        "-v", "--order-group-scope=class", "--order-scope=module"
+    )
     result.assert_outcomes(passed=14, failed=0)
     result.stdout.fnmatch_lines([
         "test_clss.py::Test2::test_one PASSED",
@@ -156,12 +167,14 @@ def test_class_group_scope_module_scope(fixture_path):
         "test_fcts3.py::test3_one PASSED",
         "test_fcts3.py::test3_two PASSED",
         "test_fcts4.py::test4_one PASSED",
-        "test_fcts4.py::test4_two PASSED"
+        "test_fcts4.py::test4_two PASSED",
     ])
 
 
-@pytest.mark.skipif(pytest.__version__.startswith("3.7."),
-                    reason="Warning does not appear in output in pytest < 3.8")
+@pytest.mark.skipif(
+    pytest.__version__.startswith("3.7."),
+    reason="Warning does not appear in output in pytest < 3.8",
+)
 def test_invalid_scope(fixture_path):
     result = fixture_path.runpytest("-v", "--order-group-scope=function")
     result.assert_outcomes(passed=14, failed=0)
@@ -170,11 +183,14 @@ def test_invalid_scope(fixture_path):
     ])
 
 
-@pytest.mark.skipif(pytest.__version__.startswith("3.7."),
-                    reason="Warning does not appear in output in pytest < 3.8")
+@pytest.mark.skipif(
+    pytest.__version__.startswith("3.7."),
+    reason="Warning does not appear in output in pytest < 3.8",
+)
 def test_ignored_scope(fixture_path):
-    result = fixture_path.runpytest("-v", "--order-group-scope=session",
-                                    "--order-scope=module")
+    result = fixture_path.runpytest(
+        "-v", "--order-group-scope=session", "--order-scope=module"
+    )
     result.assert_outcomes(passed=14, failed=0)
     result.stdout.fnmatch_lines([
         "*UserWarning: Group scope is larger than order scope, ignoring it."
