@@ -1,28 +1,33 @@
 # -*- coding: utf-8 -*-
+from textwrap import dedent
 
 import pytest
 
 
 @pytest.fixture
 def fixture_path(test_path):
-    test_a_contents = """
-import pytest
+    test_a_contents = dedent(
+        """
+        import pytest
 
-@pytest.mark.order(4)
-def test_four(): pass
+        @pytest.mark.order(4)
+        def test_four(): pass
 
-@pytest.mark.order(3)
-def test_three(): pass
-    """
-    test_b_contents = """
-import pytest
+        @pytest.mark.order(3)
+        def test_three(): pass
+        """
+    )
+    test_b_contents = dedent(
+        """
+        import pytest
 
-@pytest.mark.order(2)
-def test_two(): pass
+        @pytest.mark.order(2)
+        def test_two(): pass
 
-@pytest.mark.order(1)
-def test_one(): pass
-"""
+        @pytest.mark.order(1)
+        def test_one(): pass
+        """
+    )
     for i in range(3):
         sub_path = "feature{}".format(i)
         test_path.mkpydir(sub_path)
@@ -48,7 +53,7 @@ def test_session_scope(fixture_path):
         "feature2/test_a.py::test_three PASSED",
         "feature0/test_a.py::test_four PASSED",
         "feature1/test_a.py::test_four PASSED",
-        "feature2/test_a.py::test_four PASSED"
+        "feature2/test_a.py::test_four PASSED",
     ])
 
 
@@ -88,7 +93,7 @@ def test_dir_level1(fixture_path, capsys):
         "feature2/test_b.py::test_one PASSED",
         "feature2/test_b.py::test_two PASSED",
         "feature2/test_a.py::test_three PASSED",
-        "feature2/test_a.py::test_four PASSED"
+        "feature2/test_a.py::test_four PASSED",
     ])
 
 
@@ -108,16 +113,20 @@ def test_dir_level2(fixture_path, capsys):
         "feature2/test_a.py::test_three PASSED",
         "feature2/test_a.py::test_four PASSED",
         "feature2/test_b.py::test_one PASSED",
-        "feature2/test_b.py::test_two PASSED"
+        "feature2/test_b.py::test_two PASSED",
     ])
 
 
-@pytest.mark.skipif(pytest.__version__.startswith("3.7."),
-                    reason="Warning does not appear in output in pytest < 3.8")
+@pytest.mark.skipif(
+    pytest.__version__.startswith("3.7."),
+    reason="Warning does not appear in output in pytest < 3.8",
+)
 def test_invalid_scope(fixture_path):
-    result = fixture_path.runpytest("-v", "--order-scope=module",
-                                    "--order-scope-level=1")
+    result = fixture_path.runpytest(
+        "-v", "--order-scope=module", "--order-scope-level=1"
+    )
     result.assert_outcomes(passed=12, failed=0)
     result.stdout.fnmatch_lines([
         "*UserWarning: order-scope-level cannot be used "
-        "together with --order-scope=module*"])
+        "together with --order-scope=module*"
+    ])
